@@ -1,11 +1,16 @@
 package POE::Component::IRC::Common;
+BEGIN {
+  $POE::Component::IRC::Common::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Component::IRC::Common::VERSION = '6.52';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 
 use Encode qw(decode);
 use Encode::Guess;
-our $VERSION = '6.16';
 
 require Exporter;
 use base qw(Exporter);
@@ -50,8 +55,9 @@ use constant {
 };
 
 sub u_irc {
-    my $value = shift || return;
-    my $type = shift || 'rfc1459';
+    my ($value, $type) = @_;
+    return if !defined $value;
+    $type = 'rfc1459' if !defined $type;
     $type = lc $type;
 
     if ( $type eq 'ascii' ) {
@@ -68,8 +74,9 @@ sub u_irc {
 }
 
 sub l_irc {
-    my $value = shift || return;
-    my $type = shift || 'rfc1459';
+    my ($value, $type) = @_;
+    return if !defined $value;
+    $type = 'rfc1459' if !defined $type;
     $type = lc $type;
 
     if ( $type eq 'ascii' ) {
@@ -102,7 +109,7 @@ sub parse_mode_line {
            $statmodes = join '', keys %{ $arg };
            next;
         }
-        elsif ( $arg =~ /^(\+|-)/ or $count == 0 ) {
+        elsif ( $arg =~ /^[-+]/ or $count == 0 ) {
             my $action = '+';
             for my $char ( split (//,$arg) ) {
                 if ($char eq '+' or $char eq '-') {
@@ -112,11 +119,12 @@ sub parse_mode_line {
                    push @{ $hashref->{modes} }, $action . $char;
                 }
                 
-                if ($char =~ /[$statmodes$chanmodes->[0]$chanmodes->[1]]/) {
+                if (length $chanmodes->[0] && length $chanmodes->[1] && length $statmodes
+                    && $char =~ /[$statmodes$chanmodes->[0]$chanmodes->[1]]/) {
                     push @{ $hashref->{args} }, shift @args;
                 }
                 
-                if ($action eq '+' && $char =~ /[$chanmodes->[2]]/) {
+                if (length $chanmodes->[2] && $action eq '+' && $char =~ /[$chanmodes->[2]]/) {
                     push @{ $hashref->{args} }, shift @args;
                 }
             }
@@ -131,7 +139,8 @@ sub parse_mode_line {
 }
 
 sub parse_ban_mask {
-    my $arg = shift || return;
+    my ($arg) = @_;
+    return if !defined $arg;
 
     $arg =~ s/\x2a{2,}/\x2a/g;
     my @ban;
@@ -157,7 +166,7 @@ sub parse_ban_mask {
 sub matches_mask_array {
     my ($masks, $matches, $mapping) = @_;
     
-    return if !$masks || !$matches;
+    return if !defined $masks || !defined $matches;
     return if ref $masks ne 'ARRAY';
     return if ref $matches ne 'ARRAY';
     my $ref = { };
@@ -174,9 +183,9 @@ sub matches_mask_array {
 }
 
 sub matches_mask {
-    my ($mask,$match,$mapping) = @_;
+    my ($mask, $match, $mapping) = @_;
+    return if !defined $mask || !defined $match;
 
-    return if !$mask || !$match;
     $mask = parse_ban_mask($mask);
     $mask =~ s/\x2A+/\x2A/g;
 
@@ -190,26 +199,31 @@ sub matches_mask {
 }
 
 sub parse_user {
-    my $user = shift || return;
+    my ($user) = @_;
+    return if !defined $user;
+
     my ($n, $u, $h) = split /[!@]/, $user;
     return ($n, $u, $h) if wantarray();
     return $n;
 }
 
 sub has_color {
-    my $string = shift;
+    my ($string) = @_;
+    return if !defined $string;
     return 1 if $string =~ /[\x03\x04]/;
     return;
 }
 
 sub has_formatting {
-    my $string = shift;
+    my ($string) = @_;
+    return if !defined $string;
     return 1 if $string =~/[\x02\x1f\x16\x1d\x11]/;
     return;
 }
 
 sub strip_color {
-    my $string = shift;
+    my ($string) = @_;
+    return if !defined $string;
     
     # mIRC colors
     $string =~ s/\x03(?:,\d{1,2}|\d{1,2}(?:,\d{1,2})?)?//g;
@@ -222,7 +236,8 @@ sub strip_color {
 }
 
 sub strip_formatting {
-    my $string = shift;
+    my ($string) = @_;
+    return if !defined $string;
     $string =~ s/[\x0f\x02\x1f\x16\x1d\x11]//g;
     return $string;
 }
@@ -239,7 +254,8 @@ sub irc_to_utf8 {
 # Params            : IP address
 # Returns           : 4, 6, 0(don't know)
 sub irc_ip_get_version {
-    my $ip = shift || return;
+    my ($ip) = @_;
+    return if !defined $ip;
 
     # If the address does not contain any ':', maybe it's IPv4
     return 4 if $ip !~ /:/ && irc_ip_is_ipv4($ip);
@@ -256,7 +272,8 @@ sub irc_ip_get_version {
 # Params            : IP address
 # Returns           : 1 (yes) or 0 (no)
 sub irc_ip_is_ipv4 {
-    my $ip = shift || return;
+    my ($ip) = @_;
+    return if !defined $ip;
 
     # Check for invalid chars
     if ($ip !~ /^[\d\.]+$/) {
@@ -314,7 +331,8 @@ sub irc_ip_is_ipv4 {
 # Params            : IP address
 # Returns           : 1 (yes) or 0 (no)
 sub irc_ip_is_ipv6 {
-    my $ip = shift || return;
+    my ($ip) = @_;
+    return if !defined $ip;
 
     # Count octets
     my $n = ($ip =~ tr/:/:/);
@@ -367,7 +385,8 @@ sub irc_ip_is_ipv6 {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
@@ -513,7 +532,7 @@ Takes two parameters, a string representing an IRC mask ( it'll be processed
 with parse_ban_mask() to ensure that it is normalised ) and something to match
 against the IRC mask, such as a nick!user@hostname string. Returns a true
 value if they match, a false value otherwise. Optionally, one may pass the
-casemapping (see L<C<u_irc>|/"u_irc">), as this function uses C<u_irc>
+casemapping (see L<C<u_irc>|/u_irc>), as this function uses C<u_irc>
 internally.
 
 =head2 C<matches_mask_array>
@@ -522,7 +541,7 @@ Takes two array references, the first being a list of strings representing
 IRC masks, the second a list of somethings to test against the masks. Returns
 an empty hashref if there are no matches. Otherwise, the keys will be the
 masks matched, each value being an arrayref of the strings that matched it.
-Optionally, one may pass the casemapping (see L<C<u_irc>|/"u_irc">), as
+Optionally, one may pass the casemapping (see L<C<u_irc>|/u_irc>), as
 this function uses C<u_irc> internally.
 
 =head2 C<parse_user>
@@ -545,7 +564,7 @@ formatting codes, 0 otherwise.
 
 =head2 C<strip_color>
 
-Takes one paramter, a string of IRC text. Returns the string stripped of all
+Takes one parameter, a string of IRC text. Returns the string stripped of all
 IRC color codes. Due to the fact that both color and formatting codes can
 be cancelled with the same character, this might strip more than you hoped for
 if the string contains both color and formatting codes. Stripping both will
@@ -553,7 +572,7 @@ always do what you expect it to.
 
 =head2 C<strip_formatting>
 
-Takes one paramter, a string of IRC text. Returns the string stripped of all
+Takes one parameter, a string of IRC text. Returns the string stripped of all
 IRC formatting codes. Due to the fact that both color and formatting codes can
 be cancelled with the same character, this might strip more than you hoped for
 if the string contains both color and formatting codes. Stripping both will
@@ -561,16 +580,8 @@ always do what you expect it to.
 
 =head2 C<irc_to_utf8>
 
-The IRC messages you get from L<POE::Component::IRC|POE::Component::IRC> are
-raw byte strings that have no inherent encoding. Most popular clients (mIRC,
-xchat, certain irssi configurations) encode their messages in Microsoft's
-CP1252 encoding (their version of Latin-1) if the message only contains
-characters which fit into Latin-1, otherwise falling back to UTF-8 encoding.
-Writing something like this to a file, terminal, or database is a recipe for
-disaster.
-
 This function takes a byte string (e.g. a message from an
-L<C<irc_public>|POE::Component::IRC/"irc_public"> handler) in "IRC encoding"
+L<C<irc_public>|POE::Component::IRC/irc_public> handler) in "IRC encoding"
 and returns a text string. Since the source encoding might have been UTF-8,
 you should encode/store it in UTF-8 or some other Unicode encoding in your
 file/database/whatever.
@@ -589,9 +600,6 @@ file/database/whatever.
      print $what, "\n";
  }
 
-See also L<Encode|Encode>, L<perluniintro>, L<perlunitut>, L<perlunicode>,
-and L<perlunifaq>.
-
 =head2 C<irc_ip_get_version>
 
 Try to guess the IP version of an IP address.
