@@ -1,13 +1,17 @@
 package POE::Component::IRC::Plugin::AutoJoin;
+BEGIN {
+  $POE::Component::IRC::Plugin::AutoJoin::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Component::IRC::Plugin::AutoJoin::VERSION = '6.52';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Carp;
 use POE::Component::IRC::Plugin qw(:ALL);
 use POE::Component::IRC::Common qw(parse_user l_irc);
 
-our $VERSION = '6.16';
-
 sub new {
     my ($package) = shift;
     croak "$package requires an even number of arguments" if @_ & 1;
@@ -17,31 +21,33 @@ sub new {
 
 sub PCI_register {
     my ($self, $irc) = @_;
-    
-    if (!$irc->isa('POE::Component::IRC::State')) {
-        die  __PACKAGE__ . ' requires PoCo::IRC::State or a subclass thereof';
-    }
-    
-    if (!$self->{Channels}) {
-        for my $chan (keys %{ $irc->channels() }) {
-            my $lchan = l_irc($chan, $irc->isupport('MAPPING'));
-            my $key = $irc->is_channel_mode_set($chan, 'k')
-                ? $irc->channel_key($chan)
-                : ''
-            ;
 
-            $self->{Channels}->{$lchan} = $key;
+    if (!$self->{Channels}) {
+        if ($irc->isa('POE::Component::IRC::State')) {
+            for my $chan (keys %{ $irc->channels() }) {
+                my $lchan = l_irc($chan, $irc->isupport('MAPPING'));
+                my $key = $irc->is_channel_mode_set($chan, 'k')
+                    ? $irc->channel_key($chan)
+                    : ''
+                ;
+
+                $self->{Channels}->{$lchan} = $key;
+            }
+        }
+        else {
+            $self->{Channels} = {};
         }
     }
     elsif (ref $self->{Channels} eq 'ARRAY') {
         my %channels;
-        $channels{l_irc($_, $irc->isupport('MAPPING'))} = '' for @{ $self->{Channels} };
+        $channels{l_irc($_, $irc->isupport('MAPPING'))} = undef for @{ $self->{Channels} };
         $self->{Channels} = \%channels;
     }
 
     $self->{tried_keys} = { };
     $self->{Rejoin_delay} = 5 if !defined $self->{Rejoin_delay};
-    $irc->plugin_register($self, 'SERVER', qw(001 004 474 isupport chan_mode join kick part));
+    $self->{NickServ_delay} = 5 if !defined $self->{NickServ_delay};
+    $irc->plugin_register($self, 'SERVER', qw(001 004 474 isupport chan_mode join kick part identified));
     $irc->plugin_register($self, 'USER', qw(join));
     return 1;
 }
@@ -53,6 +59,7 @@ sub PCI_unregister {
 sub S_001 {
     my ($self, $irc) = splice @_, 0, 2;
     delete $self->{masked_key};
+    delete $self->{alarm_ids};
     return PCI_EAT_NONE;
 }
 
@@ -63,19 +70,42 @@ sub S_004 {
 
     # ircu returns '*' to non-ops instead of the real channel key
     $self->{masked_key} = 1 if $version =~ /^u\d/;
+
     return PCI_EAT_NONE;
 }
 
-# we join channels after irc_isupport for two reasons:
-# a) the NickServID plugin needs to waits for irc_004 before identifying,
-# and users may want to be cloaked before joining any channels,
-# b) if the server supports CAPAB IDENTIFY-MSG (FreeNode), that will be
-# checked for after the irc_isupport (right before we try to join channels)
+# we join channels after S_isupport in case the server supports
+# CAPAB IDENTIFY-MSG, so pocoirc can turn it on before we join channels
 sub S_isupport {
     my ($self, $irc) = splice @_, 0, 2;
     
-    while (my ($chan, $key) = each %{ $self->{Channels} }) {
-        $irc->yield(join => $chan => $key);
+    if (!grep { $_->isa('POE::Component::IRC::Plugin::NickServID') } values %{ $irc->plugin_list() }) {
+        # we don't have to wait for NickServ, so let's join
+        while (my ($chan, $key) = each %{ $self->{Channels} }) {
+            $irc->yield(join => $chan => (defined $key ? $key : ()));
+        }
+    }
+    else {
+        while (my ($chan, $key) = each %{ $self->{Channels} }) {
+            push @{ $self->{alarm_ids} }, $irc->delay(
+                [join => $chan => (defined $key ? $key : ())],
+                $self->{NickServ_delay},
+            );
+        }
+    }
+    return PCI_EAT_NONE;
+}
+
+sub S_identified {
+    my ($self, $irc) = splice @_, 0, 2;
+
+    if ($self->{alarm_ids}) {
+        $irc->delay_remove($_) for @{ $self->{alarm_ids} };
+        delete $self->{alarm_ids};
+
+        while (my ($chan, $key) = each %{ $self->{Channels} }) {
+            $irc->yield(join => $chan => (defined $key ? $key : ()));
+        }
     }
     return PCI_EAT_NONE;
 }
@@ -89,15 +119,16 @@ sub S_474 {
 
     my $key = $self->{Channels}{$lchan};
     $key = $self->{tried_keys}{$lchan} if defined $self->{tried_keys}{$lchan};
-    $irc->delay([join => $chan => $key], $self->{Retry_when_banned});
+    $irc->delay([join => $chan => (defined $key ? $key : ())], $self->{Retry_when_banned});
     return PCI_EAT_NONE;
 }
 
 sub S_chan_mode {
     my ($self, $irc) = splice @_, 0, 2;
+    pop @_;
     my $chan  = ${ $_[1] };
     my $mode  = ${ $_[2] };
-    my $arg   = ${ $_[3] };
+    my $arg   = defined $_[3] ? ${ $_[3] } : '';
     my $lchan = l_irc($chan, $irc->isupport('MAPPING'));
 
     $self->{Channels}->{$lchan} = $arg if $mode eq '+k';
@@ -112,6 +143,7 @@ sub S_join {
     my $lchan  = l_irc($chan, $irc->isupport('MAPPING'));
 
     return PCI_EAT_NONE if $joiner ne $irc->nick_name();
+    delete $self->{alarm_ids};
 
     if (defined $self->{tried_keys}{$lchan}) {
         $self->{Channels}->{$lchan} = $self->{tried_keys}{$lchan};
@@ -132,7 +164,11 @@ sub S_kick {
 
     if ($victim eq $irc->nick_name()) {
         if ($self->{RejoinOnKick}) {
-            $irc->delay([join => $chan => $self->{Channels}->{$lchan}], $self->{Rejoin_delay});
+            $irc->delay([
+                'join',
+                $chan,
+                (defined $self->{Channels}->{$lchan} ? $self->{Channels}->{$lchan} : ())
+            ], $self->{Rejoin_delay});
         }
         delete $self->{Channels}->{$lchan};
     }
@@ -159,7 +195,8 @@ sub U_join {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
@@ -212,6 +249,10 @@ on the next time it gets connected to the IRC server. It can also rejoin a
 channel if the IRC component gets kicked from it. It keeps track of channel
 keys so it will be able to rejoin keyed channels in case of reconnects/kicks.
 
+If a L<POE::Component::IRC::Plugin::NickServID|POE::Component::IRC::Plugin::NickServID>
+plugin has been added to the IRC component, then AutoJoin will wait for a
+reply from NickServ before joining channels on connect.
+
 This plugin requires the IRC component to be
 L<POE::Component::IRC::State|POE::Component::IRC::State> or a subclass thereof.
 
@@ -219,11 +260,12 @@ L<POE::Component::IRC::State|POE::Component::IRC::State> or a subclass thereof.
 
 =head2 C<new>
 
-Two optional arguments:
+Takes the following optional arguments:
 
 B<'Channels'>, either an array reference of channel names, or a hash reference
 keyed on channel name, containing the password for each channel. By default it
-uses the channels the component is already on, if any.
+uses the channels the component is already on if you are using
+L<POE::Component::IRC::State|POE::Component::IRC::State>.
 
 B<'RejoinOnKick'>, set this to 1 if you want the plugin to try to rejoin a
 channel (once) if you get kicked from it. Default is 0.
@@ -234,6 +276,9 @@ after being kicked (if B<'RejoinOnKick'> is on). Default is 5.
 B<'Retry_when_banned'>, if you can't join a channel due to a ban, set this
 to the number of seconds to wait between retries. Default is 0 (disabled).
 
+B<'NickServ_delay'>, how long (in seconds) to wait for a reply from NickServ
+before joining channels. Default is 5.
+
 Returns a plugin object suitable for feeding to
 L<POE::Component::IRC|POE::Component::IRC>'s C<plugin_add> method.
 
