@@ -1,13 +1,17 @@
 package POE::Component::IRC::Plugin::Connector;
+BEGIN {
+  $POE::Component::IRC::Plugin::Connector::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Component::IRC::Plugin::Connector::VERSION = '6.52';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Carp;
 use POE;
 use POE::Component::IRC::Plugin qw( :ALL );
 
-our $VERSION = '6.16';
-
 sub new {
     my ($package) = shift;
     croak "$package requires an even number of arguments" if @_ & 1;
@@ -22,11 +26,11 @@ sub PCI_register {
     my ($self, $irc) = splice @_, 0, 2;
 
     $self->{irc} = $irc;
-    $self->{SESSION_ID} = POE::Session->create(
+    POE::Session->create(
         object_states => [
             $self => [ qw(_start _auto_ping _reconnect _shutdown _start_ping _start_time_out _stop_ping _time_out) ],
         ],
-    )->ID();
+    );
 
     $irc->raw_events(1);
     $irc->plugin_register( $self, 'SERVER', qw(connected disconnected 001 error socketerr pong raw) );
@@ -137,6 +141,7 @@ sub _shutdown {
     my ($kernel,$self) = @_[KERNEL, OBJECT];
 
     $kernel->yield( '_stop_ping' );
+    $kernel->delay('_reconnect');
     return;
 }
 
@@ -172,7 +177,8 @@ sub _time_out {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
