@@ -1,13 +1,17 @@
 package POE::Component::IRC::Plugin::CycleEmpty;
+BEGIN {
+  $POE::Component::IRC::Plugin::CycleEmpty::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Component::IRC::Plugin::CycleEmpty::VERSION = '6.52';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Carp;
 use POE::Component::IRC::Plugin qw( :ALL );
 use POE::Component::IRC::Common qw( parse_user u_irc );
 
-our $VERSION = '6.16';
-
 sub new {
     my ($package) = shift;
     croak "$package requires an even number of arguments" if @_ & 1;
@@ -90,7 +94,8 @@ sub is_cycling {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
