@@ -1,11 +1,15 @@
 package POE::Component::IRC::Plugin::ISupport;
+BEGIN {
+  $POE::Component::IRC::Plugin::ISupport::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Component::IRC::Plugin::ISupport::VERSION = '6.52';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use POE::Component::IRC::Plugin qw(:ALL);
 
-our $VERSION = '0.58';
-
 sub new {
     return bless { }, shift;
 }
@@ -89,10 +93,11 @@ sub PCI_unregister {
     return 1;
 }
 
-sub S_001 {
+sub S_connected {
     my ($self, $irc) = splice @_, 0, 2;
 
-    $self->{server} = { };
+    $self->{server}   = { };
+    $self->{got_005}  = 0;
     $self->{done_005} = 0;
     return PCI_EAT_NONE;
 }
@@ -102,9 +107,7 @@ sub S_005 {
     my @vals = @{ ${ $args[2] } };
     pop @vals;
     my $support = $self->{server};
-    #(my $spec = ${ $args[1] }) =~ s/:are (?:available|supported).*//;
 
-    #for (split ' ', $spec) {
     for my $val (@vals) {
         if ($val =~ /=/) {
             my $key;
@@ -131,7 +134,8 @@ sub S_005 {
             }
         }
     }
-    
+
+    $self->{got_005}++;
     return PCI_EAT_NONE;
 }
 
@@ -139,8 +143,9 @@ sub _default {
     my ($self, $irc, $event) = @_;
 
     return PCI_EAT_NONE if $self->{done_005};
-    
-    if ($event =~ /^S_0*(\d+)/ and $1 > 5) {
+    return PCI_EAT_NONE if !$self->{got_005};
+
+    if ($event =~ /^S_(\d+)/ and $1 > 5) {
         $irc->send_event(irc_isupport => $self);
         $self->{done_005} = 1;
     }
@@ -166,7 +171,8 @@ sub isupport_dump_keys {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
@@ -185,7 +191,7 @@ define the capabilities support by the server.
 Takes no arguments.
 
 Returns a plugin object suitable for feeding to
-L<POE::Component::IRC|POE::Component::IRC>'s plugin_add() method.
+L<POE::Component::IRC|POE::Component::IRC>'s C<plugin_add> method.
 
 =head2 C<isupport>
 
@@ -196,7 +202,7 @@ capabilities is available at L<http://www.irc.org/tech_docs/005.html>.
 =head2 C<isupport_dump_keys>
 
 Takes no arguments, returns a list of the available server capabilities,
-which can be used with isupport().
+which can be used with C<isupport>.
 
 =head1 INPUT
 
@@ -217,7 +223,7 @@ it emits an C<irc_isupport> signal.
 
 Emitted by: the first signal received after C<irc_005>
 
-ARG0 will be the plugin object itself for ease of use.
+C<ARG0> will be the plugin object itself for ease of use.
 
 This is emitted when the support report has finished.
 
