@@ -1,13 +1,17 @@
 package POE::Component::IRC::Plugin::Whois;
+BEGIN {
+  $POE::Component::IRC::Plugin::Whois::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Component::IRC::Plugin::Whois::VERSION = '6.52';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use POE;
 use POE::Component::IRC::Plugin qw( PCI_EAT_NONE );
 use POE::Component::IRC::Common qw(:ALL);
 
-our $VERSION = '6.16';
-
 sub new {
     return bless { }, shift;
 }
@@ -174,7 +178,8 @@ sub S_369 {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
