@@ -1,14 +1,18 @@
 package POE::Component::IRC::Qnet;
+BEGIN {
+  $POE::Component::IRC::Qnet::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Component::IRC::Qnet::VERSION = '6.52';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Carp;
 use POE;
 use POE::Component::IRC::Constants qw(:ALL);
 use base qw(POE::Component::IRC);
 
-our $VERSION = '6.08';
-
 sub _create {
     my $self = shift;
 
@@ -89,7 +93,8 @@ sub service_bots {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
@@ -214,7 +219,7 @@ the event.
 =head1 OUTPUT
 
 All output from the Quakenet service bots is sent as NOTICEs.
-Use L<C<irc_notice>|POE::Component::IRC/"irc_notice"> to trap these.
+Use L<C<irc_notice>|POE::Component::IRC/irc_notice> to trap these.
 
 =head2 C<irc_whois>
 
