@@ -1,15 +1,19 @@
 package POE::Component::IRC::Qnet::State;
+BEGIN {
+  $POE::Component::IRC::Qnet::State::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Component::IRC::Qnet::State::VERSION = '6.52';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Carp;
 use POE;
 use POE::Component::IRC::Common qw(:ALL);
 use POE::Component::IRC::Plugin qw(:ALL);
 use base qw(POE::Component::IRC::State POE::Component::IRC::Qnet);
 
-our $VERSION = '6.16';
-
 sub _create {
     my $self = shift;
 
@@ -242,10 +246,11 @@ sub S_join {
 sub S_chan_mode {
     my ($self, $irc) = splice @_, 0, 2;
     my $mapping = $irc->isupport('CASEMAPPING');
+    pop @_;
     my $who = ${ $_[0] };
     my $source = u_irc ( ( split /!/, $who )[0], $mapping );
     my $mode = ${ $_[2] };
-    my $arg = ${ $_[3] };
+    my $arg = defined $_[3] ? ${ $_[3] } : '';
     my $uarg = u_irc $arg, $mapping;
     
     return PCI_EAT_NONE if $source !~ /^[Q]$/ || $mode !~ /[ov]/;
@@ -426,7 +431,8 @@ sub ban_mask {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
@@ -583,13 +589,13 @@ These additional events are accepted:
 
 Accepts a list of channels, will resynchronise each of those channels as if
 they have been joined for the first time. Expect to see an
-L<C<irc_chan_sync>|POE::Component::IRC::State/"irc_chan_sync"> event for each
+L<C<irc_chan_sync>|POE::Component::IRC::State/irc_chan_sync> event for each
 channel given.
 
 =item C<resync_nick>
 
 Accepts a nickname and a list of channels. Will resynchronise the given nickname
-and issue an L<C<irc_nick_sync>|POE::Component::IRC::State/"irc_nick_sync">
+and issue an L<C<irc_nick_sync>|POE::Component::IRC::State/irc_nick_sync>
 event for each of the given channels (assuming that nick is on each of those channels).
 
 =back
