@@ -1,13 +1,17 @@
 package POE::Filter::IRC;
+BEGIN {
+  $POE::Filter::IRC::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Filter::IRC::VERSION = '6.52';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use POE::Filter::Stackable;
 use POE::Filter::IRCD;
 use POE::Filter::IRC::Compat;
 
-our $VERSION = '6.16';
-
 sub new {
     my ($package, %opts) = @_;
     $opts{lc $_} = delete $opts{$_} for keys %opts;
@@ -20,7 +24,8 @@ sub new {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
