@@ -1,14 +1,18 @@
 package POE::Filter::IRC::Compat;
+BEGIN {
+  $POE::Filter::IRC::Compat::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $POE::Filter::IRC::Compat::VERSION = '6.52';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Carp;
 use POE::Filter::IRCD;
 use File::Basename qw(fileparse);
 use base qw(POE::Filter);
 
-our $VERSION = '6.16';
-
 my %irc_cmds = (
     qr/^\d{3}$/ => sub {
         my ($self, $event, $line) = @_;
@@ -22,6 +26,14 @@ my %irc_cmds = (
         }
         $event->{args}->[2] = $line->{params};
     },
+    qr/^cap$/ => sub {
+        my ($self, $event, $line) = @_;
+
+        for (my $i = 0; ; $i++) {
+            last if !defined $line->{params}[$i+1];
+            $event->{args}[$i] = $line->{params}[$i+1];
+        }
+    },
     qr/^notice$/ => sub {
         my ($self, $event, $line) = @_;
 
@@ -288,17 +300,26 @@ sub _get_ctcp {
 
     # Is this a CTCP request or reply?
     my $ctcp_type = $line->{command} eq 'PRIVMSG' ? 'ctcp' : 'ctcpreply';
-    
+
     # CAPAP IDENTIFY-MSG is only applied to ACTIONs
     my ($msg, $identified) = ($line->{params}->[1], undef);
     ($msg, $identified) = _split_idmsg($msg) if $self->{identifymsg} && $msg =~ /^.ACTION/;
-    
-    my ($ctcp, $text) = _ctcp_dequote($msg);
-    my $nick = defined $line->{prefix} ? (split /!/, $line->{prefix})[0] : undef;
 
     my $events = [ ];
+    my ($ctcp, $text) = _ctcp_dequote($msg);
+
+    if (!defined $ctcp) {
+        warn "Received malformed CTCP message: $msg\n" if $self->{debug};
+        return $events;
+    }
+
+    my $nick = defined $line->{prefix} ? (split /!/, $line->{prefix})[0] : undef;
+
+    # We only process the first CTCP. The only people who send multiple ones
+    # are those who are trying to flood our outgoing queue anyway (e.g. by
+    # having us reply to 20 VERSION requests at a time).
     my ($name, $args);
-    CTCP: for my $string (@$ctcp) {
+    CTCP: for my $string ($ctcp->[0]) {
         if (!(($name, $args) = $string =~ /^(\w+)(?: +(.*))?/)) {
             defined $nick
                 ? do { warn "Received malformed CTCP message from $nick: $string\n" if $self->{debug} }
@@ -306,10 +327,10 @@ sub _get_ctcp {
             ;
             last CTCP;
         }
-            
+
         if (lc $name eq 'dcc') {
             my ($dcc_type, $rest);
-            
+
             if (!(($dcc_type, $rest) = $args =~ /^(\w+) +(.+)/)) {
                 defined $nick
                     ? do { warn "Received malformed DCC request from $nick: $args\n" if $self->{debug} }
@@ -412,7 +433,8 @@ sub _low_dequote {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
